@@ -637,8 +637,10 @@ connectBigQuery <- function(connectionDetails) {
 
 connectSpark <- function(connectionDetails) {
   inform("Connecting using Spark JDBC driver")
-  jarPath <- findPathToJar("^SparkJDBC42\\.jar$", connectionDetails$pathToDriver)
-  driver <- getJbcDriverSingleton("com.simba.spark.jdbc.Driver", jarPath)
+  # jarPath <- findPathToJar("^SparkJDBC42\\.jar$", connectionDetails$pathToDriver)
+  jarPath <- findPathToJar("^DatabricksJDBC42\\.jar$", connectionDetails$pathToDriver)
+  # driver <- getJbcDriverSingleton("com.simba.spark.jdbc.Driver", jarPath)
+  driver <- getJbcDriverSingleton("com.databricks.client.jdbc.Driver", jarPath)
   connectionString <- connectionDetails$connectionString()
   if (is.null(connectionString) || connectionString == "") {
     abort("Error: Connection string required for connecting to Spark.")
@@ -673,8 +675,8 @@ connectSparkUsingOdbc <- function(connectionDetails) {
     Host = connectionDetails$server(),
     uid = connectionDetails$user(),
     pwd = connectionDetails$password(),
-    Port = connectionDetails$port(),
-    UseNativeQuery=1
+    Port = connectionDetails$port()
+    # UseNativeQuery=1
   )
   if (!is.null(connectionDetails$extraSettings)) {
     dbiConnectionDetails <- append(
